class Nukumi
  module Flavor
    class XML
      def make_header
        vers = Nukumi::VERSION + Nukumi::REVISION

        %{<?xml version="1.0" encoding="utf-8"?>
           <blog version="#{vers.xmlescape}"
                 date="#{Time.now.rfc822.xmlescape}"
                 xdate="#{Time.now.gmtime.xmlschema.xmlescape}">}
      end
  
      def make_entry(entry)
        unless @cache[entry]
          s = "<entry>\n"
          entry.header.each { |field, value|
            field = field.downcase
            s << "  <#{field}>#{value.xmlescape}</#{field}>\n"
          }
          
          entry.keys.each { |key, value|
            value.each { |v|
              s << %{  <key name="#{key.downcase.xmlescape}">#{v.xmlescape}</key>\n}
            }
          }
          s << %{  <body xmlns="http://www.w3.org/1999/xhtml">
                     #{entry.format.new(entry.body).to_html}
                   </body>
                 </entry>\n\n}

          @cache[entry] = s
        else
          @cache[entry]
        end
      end
      
      def make_footer
        unless @footer
          s = ''
          @views.each { |v|
            s << %{<view name="#{v.name.downcase.xmlescape}">\n}
            v.keys.each { |a|
              [*a].each { |b|
                s << "  <item>#{b.xmlescape}</item>\n"
              }
            }
            s << "</view>\n"
          }
          s << "</blog>\n"
          @footer = s
        else
          @footer
        end
      end  
      
      def generate_output(xml, output, params={})
        puts "Making #{output}"

        params["flavor"] ||= self.class.to_s.gsub(/^.*::/, '').downcase
        params["to_root"] ||= ("../" * (output.count("/")-1))
        params["config"] = File.expand_path(params["config"] ||= "config.xml")

        stylesheet = lookup_stylesheet self.class::STYLESHEET

        # Hail to shell escaping!
        @cmdline = "xsltproc --xinclude " << params.map { |(k,v)|
          "--stringparam '#{k.shescape}' '#{v.shescape}'"
        }.join(" ") << " '#{stylesheet.shescape}' -"

#        p @cmdline

        result = ""
        
        File.popen(@cmdline, "w+") { |xsltproc|
          xsltproc.write xml
          xsltproc.flush
          xsltproc.close_write
          
          result = xsltproc.read
        }
        
        unless $?.exitstatus == 0
          abort "Error during XSLT processing."
        end
        
        File.open(output, "w") { |f| f.write result }
      end

      def lookup_stylesheet(stylesheet)
        bindir = File.dirname __FILE__

        dir = [
          ".", File.join(".", "share"), bindir, File.join(bindir, "share")
        ].find { |prefix|
          File.exist? File.join(prefix, stylesheet)
        }

        File.join(dir, stylesheet)
      end

      def initialize
        @cache = {}
        @footer = nil
      end

      def generate(entries, filename, key, view, views, config)
        @views = views

        xml = make_header
        entries.each { |e| xml << make_entry(e) }
        xml << make_footer
        
        generate_output xml, filename, {'key'  => key,
             'view' => view.class.to_s.gsub(/^.*::/, '').downcase}.
             merge(config)
      end
    end

    class XHTML < XML
      STYLESHEET = "xml2xhtml.xsl"
      EXTENSION  = "html"
    end

    class RSS2 < XML
      STYLESHEET = "xml2rss.xsl"
      EXTENSION  = "rss"
    end

    class Atom < XML
      STYLESHEET = "xml2atom.xsl"
      EXTENSION  = "atom"
    end
  end
end

# arch-tag: cc51ee08-50fc-4875-9c44-0f0442230072
