class Nukumi
  class View
    class Front < View
      FRONT_LENGTH = 15

      def generate_key(entry, index)
        return nil  if entry.header["Hidden"] == "true"

        (index < FRONT_LENGTH ? "index" : nil)
      end
    end

    class Archive < View
      def generate_key(entry, index)
        "archive"
      end
    end

    class Month < View
      def generate_key(entry, index)
        entry.time.strftime("%Y/%m/index")
      end
    end

    class Entry < View
      def generate_key(entry, index)
        entry.time.strftime("%Y/%m/%d-") + \
        entry.header["Subject"].downcase.strip.gsub(/[^a-z0-9]/, '-').
              squeeze('-').gsub(/^-*/, '').gsub(/-*$/, '')
      end
    end

    class Category < View
      def generate_key(entry, index)
        if entry.header["Category"] =~ /^\w+$/
          entry.header["Category"].split.map {|c| "category-" + c.downcase }
        else
          nil
        end
      end
    end

    class Page < Nukumi::View
      def generate_key(entry, index)
        if entry.header["Page"] =~ /\w+/
          entry.header["Page"].strip
        else
          nil
        end
      end
    end


    attr_accessor :keys

    def initialize
      @keys = []
    end

    def name
      self.class.to_s.gsub(/^.*::/, '')
    end

    # By default, sort by time reversed (new entries first).
    def cmp(a, b)
      b.time <=> a.time
    end
  end
end

# arch-tag: 55bdd1f9-d8c3-418f-8675-278664bcbec8
