;;; nukumi.el --- convenience functions for the nukumi blogging system

;; Copyright (C) 2004 Christian Neukirchen

;; Author: Christian Neukirchen <chneukirchen@yahoo.de>
;; Maintainer: Christian Neukirchen <chneukirchen@yahoo.de>
;; Keywords: convenience
;; Version: see `nukumi-version'

;; This file is *not* part of GNU Emacs.

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(defvar nukumi-version "0.1" "Nukumi version information.")

(defvar nukumi-blogs
  '(("chrisblogs" "~/projects/nukumi" "chrisblogsrc")
    ("nukumi"     "~/projects/nukumi" "nukumirc"    )
    )
  "A list of blogs known to nukumi.el.\n
Each element has the form (NAME DIRECTORY RC-FILE).")

(defface nukumi-field-face
  '((t (:bold t :underline t :background "grey25")))
  "Face to use for RFC822 header fields in nukumi-mode."
  :group 'font-lock-highlighting-faces)

(defface nukumi-value-face
  '((t (:bold t :background "grey25")))
  "Face to use for RFC822 header values in nukumi-mode."
  :group 'font-lock-highlighting-faces)

(defface nukumi-leading-space-face
  '((t (:background "grey40")))
  "Face to use for leading space in nukumi-mode."
  :group 'font-lock-highlighting-faces)

(defface nukumi-trailing-space-face
  '((t (:background "grey40")))
  "Face to use for trailing space in nukumi-mode."
  :group 'font-lock-highlighting-faces)

(defun nukumi-get-blog ()
  "Ask for a valid blog name."
  (completing-read "Blog: "
		    (mapcar (lambda (x) (list (car x) (car x))) nukumi-blogs)
		    nil nil (caar nukumi-blogs)))

(defun nukumi-update-blog (blog)
  "Update the blog."
  (interactive (list (nukumi-get-blog)))
  (let ((directory (cadr (assoc blog nukumi-blogs)))
	(rcfile    (caddr (assoc blog nukumi-blogs))))
    (if (and directory rcfile)
	(compile (concat "cd " directory " ; nukumi.rb --rc-file " rcfile))
      (error "No such blog: %s" blog))))

(defun nukumi-upload-blog (blog)
  "Upload the blog."
  (interactive (list (nukumi-get-blog)))
  (let ((directory (cadr (assoc blog nukumi-blogs)))
	(rcfile    (caddr (assoc blog nukumi-blogs))))
    (if (and directory rcfile)
	(compile (concat "cd " directory " ; nukumi.rb --rc-file " rcfile " upload"))
      (error "No such blog: %s" blog))))

(defun nukumi-insert-now-playing ()
  "Insert a ``now playing''-line of the current XMMS song."
  (interactive)
  (insert (shell-command-to-string
	   (concat "grep ^Title: /tmp/xmms-info_`whoami`.0 | "
		   "sed 's/^Title: /NP: /;s/ *- */---/'"))))

(defun nukumi-new-blog-entry ()
  "Start a new blog entry.\n
Call this function inside an empty buffer."
  (interactive)
  (goto-char (point-min))
  (insert "Subject: \n"
	  "Date: "
	  (format-time-string "%a, %_d %b %Y %H:%M:%S %z" (current-time))
	  "\nEncoding: BlueCloth\nCategory: \n\n")
  (nukumi-insert-now-playing)
  (goto-char (point-min))
  (end-of-line)
  (nukumi-mode))

(define-derived-mode nukumi-mode
  text-mode "Nukumi"
  "Major mode for editing nukumi weblog entries."
  (make-local-variable 'font-lock-defaults)
  (setq font-lock-defaults
	'((("^\\([A-Z][A-Za-z0-9_]*:\\)\\(.*\n\\)"
	    (1 'nukumi-field-face)
	    (2 'nukumi-value-face))
	   ("^\t" . 'nukumi-leading-space-face)
	   ("^    " . 'nukumi-leading-space-face)
	   ("  $" . 'nukumi-trailing-space-face)
	   )
	  t t)
  )
  (font-lock-mode 1)
  (set-buffer-file-coding-system 'utf-8))

(define-key nukumi-mode-map (kbd "C-c C-c") 'nukumi-update-blog)
(define-key nukumi-mode-map (kbd "C-c C-u") 'nukumi-upload-blog)

(global-set-key (kbd "C-x N") 'nukumi-new-blog-entry)

(provide 'nukumi)

;; arch-tag: 44389693-63df-469c-9558-e84ae74a9b5b
;;; nukumi.el ends here
