<!DOCTYPE stylesheet [
  <!ENTITY version  "0.6.1">
]>
<xsl:stylesheet version="1.0"
		xmlns="http://www.w3.org/1999/xhtml"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:xhtml="http://www.w3.org/1999/xhtml"
		exclude-result-prefixes="xhtml">
  
  <xsl:output
     method="xml"
     indent="yes"
     encoding="iso-8859-1"
     doctype-public="-//W3C//DTD XHTML 1.1//EN"
     doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd" />

  <xsl:param name="cfg" select="document($config)/config" />

  <xsl:template match="/">
    <xsl:variable name="e" select="/blog/entry[1]" />
    
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="{$cfg/language}">
      <head>
	<title>
	  <xsl:value-of select="$cfg/title" /> --
	  <xsl:choose>
	    <xsl:when test="$view='front'">Front page</xsl:when>
	    <xsl:when test="$view='archive'">Overview of archives</xsl:when>
	    <xsl:when test="$view='month'">
	      Archive of <xsl:value-of
                select="substring($e/key[@name='month'], 1, 7)" />
	    </xsl:when>
	    <xsl:when test="$view='entry'">
	      <xsl:value-of
                select="substring($e/key[@name='entry'], 1, 10)" />:
		<xsl:value-of select="$e/subject" />
	    </xsl:when>
	    <xsl:when test="$view='page'">
	      <xsl:value-of select="$e/subject" />	      
	    </xsl:when>
	  </xsl:choose>
	</title>

	<link rel="stylesheet" type="text/css" href="{$to_root}{$cfg/css}" />

	<link rel="alternate" type="application/rss+xml"
	      title="RSS" href="index.rss" />
	<link rel="alternate" type="application/atom+xml"
	      title="Atom" href="index.atom" />

	<link rev="made" href="mailto:{$cfg/mailto}" />

	<meta name="author" content="{$cfg/author}" />
	<meta name="generator" content="Nukumi {/blog/@version}" />
	<meta name="DC.Title" content="{$cfg/title}" />
	<meta name="DC.Creator" content="{$cfg/author}" />
      </head>

      <body>
	<div class="main">
	  <h1><a href="{$to_root}index.html"><span><xsl:value-of select="$cfg/title"/></span></a></h1>
	  
	  <div class="breadcumbs">
	    <xsl:choose>
	      <xsl:when test="$view='front'">
		&#8594; <a href="{$to_root}archive.html">Archive</a>
	      </xsl:when>
	      <xsl:otherwise>
	        You are here:
	    <a href="{$to_root}index.html">Front</a>
	      &#8594;<a href="{$to_root}archive.html">Archive</a>
	      <xsl:if test="$view!='archive' and $view!='category' and $view!='page'">
		&#8594;<a href="{$to_root}{$e/key[@name='month']}.html">
		  <xsl:value-of select="substring($e/key[@name='month'], 1, 7)"/>
		</a>
	      </xsl:if>
	      <xsl:if test="$view='category'">
		<!-- bleech -->
		&#8594;<a href="{$to_root}{$e/key[@name='entry']}.html">Category
		<xsl:value-of select="concat(translate(substring($e/key[@name=
		    'category'], 10, 1),
		    'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'),
		    substring($e/key[@name='category'], 11))" />
		</a>
	      </xsl:if>
	      <xsl:if test="$view='entry'">
		&#8594;<a href="{$to_root}{$e/key[@name='entry']}.html">
		  <xsl:value-of select="$e/subject" />
		</a>
	      </xsl:if>
	      <xsl:if test="$view='page'">
		&#8594;<a href="{$to_root}{$e/key[@name='page']}.html">
		  <xsl:value-of select="$e/subject" />
		</a>
	      </xsl:if>
	      </xsl:otherwise>
	    </xsl:choose>
	  </div>

	  <xsl:call-template name="sidebar" />

	  <div class="content">
	  <xsl:choose>
	    <xsl:when test="$view='front' or $view='entry'">
	      <xsl:apply-templates select="//entry" />
	    </xsl:when>
	    
	    <xsl:when test="$view='page'">
	      <xsl:apply-templates select="//entry" mode="page" />	      
	    </xsl:when>

	    <xsl:when test="$view='month' or $view='category'">
		<xsl:apply-templates select="//entry" mode="overview" />
	    </xsl:when>

	    <xsl:when test="$view='archive'">
	      Available archives:
	      <ul>
		<xsl:for-each select="/blog/view[@name='month']/item">
		  <li>
		    <a href="{$to_root}{.}.html">
		      <xsl:value-of select="substring(., 1, 7)" />
		    </a>
		  </li>
		</xsl:for-each>
	      </ul>
	    </xsl:when>

	    <xsl:otherwise>
	      Unhandled view <xsl:value-of select="$view" />
	    </xsl:otherwise>
	  </xsl:choose>
	  </div>

	<div class="info">
	  <a href="{$to_root}index.rss" id="rss">RSS 2.0</a>
	  <a href="{$to_root}index.atom" id="atom">Atom 0.3</a>

	  <div class="check">
	    Check: 
	    <a href="http://validator.w3.org/check/referer">XHTML</a> |
	    <a href="http://jigsaw.w3.org/css-validator/validator?uri={$cfg/base-uri}{$cfg/css}">CSS</a> |
	    <a href="http://www.contentquality.com/mynewtester/cynthia.exe?Url1={$cfg/base-uri}index.html">508</a> |
	    <a href="http://feedvalidator.org/check.cgi?url={$cfg/base-uri}index.rss">RSS</a> |
	    <a href="http://feedvalidator.org/check.cgi?url={$cfg/base-uri}index.atom">Atom</a>
	  </div>
	  <div class="versions">
	    Generated by Nukumi <xsl:value-of
	    select="/blog/@version" /> &amp; xml2xhtml.xsl &version; on
	    <xsl:value-of select="/blog/@date" />.
	  </div>
	</div>
	  <div class="imprint">
	    Copyright &#169; <xsl:value-of select="$cfg/years"/>
	    <xsl:text> </xsl:text>
	    <a href="mailto:{$cfg/mailto}">
	      <xsl:value-of select="$cfg/author" />
	    </a>
	    <br />
	    Verbatim copying is permitted as long as this message is preserved.
	  </div>
	</div>
      </body>
    </html>
    
  </xsl:template>

  <xsl:template match="entry">
    <div class="entry">
      <h3 id="{permalink}"><xsl:value-of select="subject" /></h3>
      <h4><a href="{$to_root}{key[@name='entry']}.html#{permalink}" title="Permalink"><xsl:value-of select="date" /></a></h4>

      <xsl:if test="$view!='month'">
	<xsl:apply-templates select="xhtml:body" />
      </xsl:if>
    </div>
  </xsl:template>

  <xsl:template match="entry" mode="page">
    <div class="entry page">
      <h3 id="{permalink}"><xsl:value-of select="subject" /></h3>
      <h4><a href="{$to_root}{key[@name='page']}.html"><xsl:value-of select="date" /></a></h4>

      <xsl:apply-templates select="xhtml:body" />
    </div>
  </xsl:template>

  <xsl:template match="entry" mode="overview">
    <div class="entry compact">
      <h3 id="{permalink}">
	<a href="{$to_root}{key[@name='entry']}.html#{permalink}">
	  <xsl:value-of select="subject" />
	</a>
      </h3>
      <xsl:apply-templates select="xhtml:body/xhtml:p[1]" mode="overview"/>
    </div>
  </xsl:template>

  <xsl:template match="xhtml:body/xhtml:p[1]" mode="overview">
    <xsl:copy>
      <xsl:apply-templates />
      <a href="{$to_root}{../../key[@name='entry']}.html#{../../permalink}" class="morelink">
	(more…)
      </a>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="xhtml:body">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="xhtml:img">
    <xsl:copy>
      <xsl:copy-of select="@*" />
      <xsl:if test="not(starts-with(@src, '/')) and not(contains(@src, '://'))">
	<xsl:attribute name="src">
	  <xsl:value-of select="concat($to_root, @src)" />
	</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates />      
    </xsl:copy>
  </xsl:template>

  <xsl:template name="sidebar">
    <xsl:comment>sidebar</xsl:comment>
    <div class="sidebar">
      <xsl:call-template name="toc" />
    </div>
  </xsl:template>

  <xsl:template name="toc">
    <xsl:if test="$view!='archive'">
      <h2>Table of Contents</h2>
      <ul id="toc">
	<xsl:for-each select="//entry/subject">
	  <li>
	    <a href="#{../permalink}" title="{../date}">
	      <xsl:value-of select="." />
	    </a>
	  </li>
	</xsl:for-each>
      </ul>
    </xsl:if>    
  </xsl:template>

 <!-- copy the rest -->
  <xsl:template match="xhtml:*|@*|text()">
    <xsl:copy>
      <xsl:apply-templates select="xhtml:*|@*|text()"/>
    </xsl:copy>
  </xsl:template>

  <!-- remove empty paragraphs -->
  <xsl:template match="xhtml:p[normalize-space(text())='' and not(child::*)]"/>

  <!-- remove any PIs -->
  <xsl:template match="processing-instruction()">
  </xsl:template>

  <!-- arch-tag: 33d992dd-998f-4994-8b03-0d35a07dca7b
       (do not change this comment)--> 
</xsl:stylesheet>
